summaryrefslogtreecommitdiffstats
path: root/Lib/lib-tk
diff options
context:
space:
mode:
Diffstat (limited to 'Lib/lib-tk')
-rw-r--r--Lib/lib-tk/tkFont.py3
1 files changed, 2 insertions, 1 deletions
diff --git a/Lib/lib-tk/tkFont.py b/Lib/lib-tk/tkFont.py
index 51cf9c3..7fed99d 100644
--- a/Lib/lib-tk/tkFont.py
+++ b/Lib/lib-tk/tkFont.py
@@ -21,6 +21,7 @@ import Tkinter
# weight/slant
NORMAL = "normal"
+ROMAN = "roman"
BOLD = "bold"
ITALIC = "italic"
@@ -37,7 +38,7 @@ class Font:
family -- font 'family', e.g. Courier, Times, Helvetica
size -- font size in points
weight -- font thickness: NORMAL, BOLD
slant -- font slant: NORMAL, ITALIC
underline -- font underlining: false (0), true (1)
overstrike -- font strikeout: false (0), true (1)
name -- name to use for this font configuration (defaults to a unique name)
@@ -37,7 +38,7 @@ class Font:
size -- font size in points
weight -- font thickness: NORMAL, BOLD
- slant -- font slant: NORMAL, ITALIC
+ slant -- font slant: ROMAN, ITALIC
underline -- font underlining: false (0), true (1)
overstrike -- font strikeout: false (0), true (1)